#
# spec file for package python-gast
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define srcname gast
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-gast
Version:        0.5.3
Release:        2.3
Summary:        Python AST that abstracts the underlying Python version
License:        BSD-3-Clause
URL:            https://github.com/serge-sans-paille/gast/
Source:         https://github.com/serge-sans-paille/gast/archive/%{version}.tar.gz#/%{srcname}-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module astunparse}
BuildRequires:  fdupes
BuildArch:      noarch
%python_subpackages

%description

A generic AST to represent Python2 and Python3's Abstract Syntax Tree(AST).

GAST provides a compatibility layer between the AST of various Python versions,
as produced by ``ast.parse`` from the standard ``ast`` module.

%prep
%setup -q -n gast-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v tests

%files %{python_files}
%{python_sitelib}/*
%doc README.rst
%license LICENSE

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Jan 20 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.5.3:
  + Support gast.unparse.
- Changes from version 0.5.2:
  + Test field count more accurately.
- Changes from verison 0.5.1:
  + Support NamedExpr.
  + Cleanup and optimize the way gast builds its AST.
- Changes from version 0.5.0:
  + Support AST change for 3.10.
* Mon May 24 2021 pgajdos@suse.com
- %%check: use %%pyunittest macro
* Wed Aug 26 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.0:
  * Support Python 3.9
* Mon Apr  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.3.3
  * Fix conversion of complex literals
  * Fix Ellipsis support
  * Fix conversion of arguments nodes in Python 3.8
  * Use an immutable instead of a dict to store initial table
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.0:
  * support python 3.8
* Mon Jul 29 2019 Christian Goll <cgoll@suse.com>
- inital commit of gast created with py2pack version 0.2.2
